==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/sk.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítavanie ukážky...",
    "Saved" : "Uložené",
    "Admin" : "Správca",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Name cannot be empty" : "Názov nemôže byť prázdny",
    "The given name is too long" : "Zadané meno je príliš dlhé",
    "The given web address is too long" : "Zadaná web adresa je príliš dlhá",
    "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
    "The given color is invalid" : "Zadaná farba nie je platná",
    "There is no error, the file uploaded with success" : "Nenastala žiadna chyba, súbor bol úspešne nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Failed to write file to disk." : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload." : "rozšírenie PHP zastavilo nahrávanie súboru.",
    "No file uploaded" : "Žiadny súbor nebol nahraný",
    "Unsupported image type" : "Typ obrázka nie je podporovaný",
    "You are already using a custom theme" : "Už používate upravený vzhľad",
    "Theming" : "Zmena vzhľadu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Toto bude viditeľné pre všetkých klientov.",
    "Name" : "Názov",
    "Reset to default" : "Nastaviť predvolené",
    "Web address" : "Web adresa",
    "Web address https://…" : "Webová adresa https://...",
    "Slogan" : "Slogan",
    "Color" : "Farba",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrať nové logo",
    "Login image" : "Prihlasovací obrázok",
    "Upload new login background" : "Nahrať nové prihlasovacie pozadie",
    "Remove background image" : "Odstrániť obrázok pozadia",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ak chcete automaticky generovať favikony na základe nahraného loga a farby, nainštalujte rozšírenie Imagemagick PHP s podporou pre SVG obrázky.",
    "reset to default" : "nastaviť predvolené",
    "The uploaded file was only partially uploaded" : "Ukladaný súbor sa nahral len čiastočne"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-14.0.1.tgz: nextcloud/apps/theming/l10n/sk.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítavanie ukážky...",
    "Saved" : "Uložené",
    "Admin" : "Správca",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Name cannot be empty" : "Názov nemôže byť prázdny",
    "The given name is too long" : "Zadané meno je príliš dlhé",
    "The given web address is too long" : "Zadaná web adresa je príliš dlhá",
    "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
    "The given color is invalid" : "Zadaná farba nie je platná",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor sa nahral len čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload" : "rozšírenie PHP zastavilo nahrávanie súboru.",
    "No file uploaded" : "Žiadny súbor nebol nahraný",
    "Unsupported image type" : "Typ obrázka nie je podporovaný",
    "Theming" : "Zmena vzhľadu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Toto bude viditeľné pre všetkých klientov.",
    "Name" : "Názov",
    "Reset to default" : "Nastaviť predvolené",
    "Slogan" : "Slogan",
    "Color" : "Farba",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrať nové logo",
    "Login image" : "Prihlasovací obrázok",
    "Upload new login background" : "Nahrať nové prihlasovacie pozadie",
    "Remove background image" : "Odstrániť obrázok pozadia",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ak chcete automaticky generovať favikony na základe nahraného loga a farby, nainštalujte rozšírenie Imagemagick PHP s podporou pre SVG obrázky.",
    "You are already using a custom theme" : "Už používate upravený vzhľad",
    "reset to default" : "nastaviť predvolené",
    "Web address" : "Web adresa",
    "Web address https://…" : "Webová adresa https://...",
    "There is no error, the file uploaded with success" : "Nenastala žiadna chyba, súbor bol úspešne nahraný",
    "The uploaded file was only partially uploaded" : "Ukladaný súbor sa nahral len čiastočne",
    "Failed to write file to disk." : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload." : "rozšírenie PHP zastavilo nahrávanie súboru."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
